==> moodle_1.3.1.orig.tar.gz: moodle/lang/en/assignment.php <==
<?PHP // $Id: assignment.php,v 1.23 2004/03/22 14:49:08 moodler Exp $ 
      // assignment.php - created with Moodle 1.2 + (2004032100)


$string['allowresubmit'] = 'Allow resubmitting';
$string['assignmentdetails'] = 'Assignment details';
$string['assignmentmail'] = '$a->teacher has posted some feedback on your
assignment submission for \'$a->assignment\'

You can see it appended to your assignment submission:

    $a->url';
$string['assignmentmailhtml'] = '$a->teacher has posted some feedback on your
assignment submission for \'<i>$a->assignment</i>\'<br /><br />
You can see it appended to your <a href=\"$a->url\">assignment submission</a>.';
$string['assignmentname'] = 'Assignment name';
$string['assignmenttype'] = 'Assignment type';
$string['configmaxbytes'] = 'Default maximum assignment size for all assignments on the site (subject to course limits and other local settings)';
$string['description'] = 'Description';
$string['duedate'] = 'Due date';
$string['duedateno'] = 'No due date';
$string['early'] = '$a early';
$string['existingfiledeleted'] = 'Existing file has been deleted: $a';
$string['failedupdatefeedback'] = 'Failed to update submission feedback for user $a';
$string['feedback'] = 'Feedback';
$string['feedbackupdated'] = 'Submissions feedback updated for $a people';
$string['late'] = '$a late';
$string['maximumgrade'] = 'Maximum grade';
$string['maximumsize'] = 'Maximum size';
$string['modulename'] = 'Assignment';
$string['modulenameplural'] = 'Assignments';
$string['newsubmissions'] = 'Assignments submitted';
$string['notgradedyet'] = 'Not graded yet';
$string['notsubmittedyet'] = 'Not submitted yet';
$string['overwritewarning'] = 'Warning: uploading again will REPLACE your current submission';
$string['saveallfeedback'] = 'Save all my feedback';
$string['submissionfeedback'] = 'Submission feedback';
$string['submissions'] = 'Submissions';
$string['submitassignment'] = 'Submit your assignment using this form';
$string['submitted'] = 'Submitted';
$string['typeoffline'] = 'Offline activity';
$string['typeuploadsingle'] = 'Upload a single file';
$string['uploadbadname'] = 'This filename contained strange characters and couldn\'t be uploaded';
$string['uploadedfiles'] = 'uploaded files';
$string['uploaderror'] = 'An error happened while saving the file on the server';
$string['uploadfailnoupdate'] = 'File was uploaded OK but could not update your submission!';
$string['uploadfiletoobig'] = 'Sorry, but that file is too big (limit is $a bytes)';
$string['uploadnofilefound'] = 'No file was found - are you sure you selected one to upload?';
$string['uploadnotregistered'] = '\'$a\' was uploaded OK but submission did not register!';
$string['uploadsuccess'] = 'Uploaded \'$a\' successfully';
$string['viewfeedback'] = 'View assignment grades and feedback';
$string['viewsubmissions'] = 'View $a submitted assignments';
$string['yoursubmission'] = 'Your submission';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/en/assignment.php <==
<?php // $Id$ 
      // assignment.php - created with Moodle 1.2 + (2004032100)


$string['allowresubmit'] = 'Allow resubmitting';
$string['assignmentdetails'] = 'Assignment details';
$string['assignmentmail'] = '$a->teacher has posted some feedback on your
assignment submission for \'$a->assignment\'

You can see it appended to your assignment submission:

    $a->url';
$string['assignmentmailhtml'] = '$a->teacher has posted some feedback on your
assignment submission for \'<i>$a->assignment</i>\'<br /><br />
You can see it appended to your <a href=\"$a->url\">assignment submission</a>.';
$string['assignmentname'] = 'Assignment name';
$string['assignmenttype'] = 'Assignment type';
$string['configmaxbytes'] = 'Default maximum assignment size for all assignments on the site (subject to course limits and other local settings)';
$string['description'] = 'Description';
$string['duedate'] = 'Due date';
$string['duedateno'] = 'No due date';
$string['early'] = '$a early';
$string['emailteachers'] = 'Email alerts to teachers';
$string['emailteachermail'] = '
$a->username has updated their assignment submission 
for \'$a->assignment\'

It is available here:

    $a->url';
$string['emailteachermailhtml'] = '$a->username has updated their assignment submission 
for <i>\'$a->assignment\'</i><br /><br />
It is <a href=\"$a->url\">available on the web site</a>.';
$string['existingfiledeleted'] = 'Existing file has been deleted: $a';
$string['failedupdatefeedback'] = 'Failed to update submission feedback for user $a';
$string['feedback'] = 'Feedback';
$string['feedbackupdated'] = 'Submissions feedback updated for $a people';
$string['late'] = '$a late';
$string['maximumgrade'] = 'Maximum grade';
$string['maximumsize'] = 'Maximum size';
$string['modulename'] = 'Assignment';
$string['modulenameplural'] = 'Assignments';
$string['newsubmissions'] = 'Assignments submitted';
$string['notgradedyet'] = 'Not graded yet';
$string['notsubmittedyet'] = 'Not submitted yet';
$string['overwritewarning'] = 'Warning: uploading again will REPLACE your current submission';
$string['saveallfeedback'] = 'Save all my feedback';
$string['submissionfeedback'] = 'Submission feedback';
$string['submissions'] = 'Submissions';
$string['submitassignment'] = 'Submit your assignment using this form';
$string['submitted'] = 'Submitted';
$string['typeoffline'] = 'Offline activity';
$string['typeuploadsingle'] = 'Upload a single file';
$string['uploadbadname'] = 'This filename contained strange characters and couldn\'t be uploaded';
$string['uploadedfiles'] = 'uploaded files';
$string['uploaderror'] = 'An error happened while saving the file on the server';
$string['uploadfailnoupdate'] = 'File was uploaded OK but could not update your submission!';
$string['uploadfiletoobig'] = 'Sorry, but that file is too big (limit is $a bytes)';
$string['uploadnofilefound'] = 'No file was found - are you sure you selected one to upload?';
$string['uploadnotregistered'] = '\'$a\' was uploaded OK but submission did not register!';
$string['uploadsuccess'] = 'Uploaded \'$a\' successfully';
$string['viewfeedback'] = 'View assignment grades and feedback';
$string['viewsubmissions'] = 'View $a submitted assignments';
$string['yoursubmission'] = 'Your submission';

?>
